==> mozc_2.23.2815.102+dfsg.orig.tar.xz: mozc-2.23.2815.102+dfsg/src/engine/chromeos_engine_factory.h <==
// Copyright 2010-2018, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_ENGINE_CHROMEOS_ENGINE_FACTORY_H_
#define MOZC_ENGINE_CHROMEOS_ENGINE_FACTORY_H_

#include "data_manager/chromeos/chromeos_data_manager.h"
#include "engine/engine.h"

namespace mozc {

// Provides the factory method that creates an instance of Engine that is
// equipped with the data set for Chromeos (i.e.,
// mozc/data/dictionary_chromeos).
class ChromeOsEngineFactory {
 public:
  // Creates an instance of Engine class. The caller is responsible for deleting
  // the returned object.
  static Engine *Create() {
    return Engine::CreateDesktopEngineHelper<chromeos::ChromeOsDataManager>()
        .release();
  }
};

}  // namespace mozc

#endif  // MOZC_ENGINE_CHROMEOS_ENGINE_FACTORY_H_

==> mozc_2.26.4220.100+dfsg.orig.tar.xz: mozc-2.26.4220.100+dfsg/src/engine/chromeos_engine_factory.h <==
// Copyright 2010-2020, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_ENGINE_CHROMEOS_ENGINE_FACTORY_H_
#define MOZC_ENGINE_CHROMEOS_ENGINE_FACTORY_H_

#include "data_manager/chromeos/chromeos_data_manager.h"
#include "engine/engine.h"

namespace mozc {

// Provides the factory method that creates an instance of Engine that is
// equipped with the data set for Chromeos (i.e.,
// mozc/data/dictionary_chromeos).
class ChromeOsEngineFactory {
 public:
  // Creates an instance of Engine class. The caller is responsible for deleting
  // the returned object.
  static Engine *Create() {
    auto engine =
        Engine::CreateDesktopEngineHelper<chromeos::ChromeOsDataManager>();
    if (!engine.ok()) {
      LOG(ERROR) << engine.status();
      return nullptr;
    }
    return engine->release();
  }
};

}  // namespace mozc

#endif  // MOZC_ENGINE_CHROMEOS_ENGINE_FACTORY_H_
